@@ -2,8 +2,8 @@
                           help.h  -  description
                              -------------------
     begin                : Die Apr 23 2002
-    copyright            : (C) 2002-2007 by Andre Simon
-    email                : andre.simon1@gmx.de
+    copyright            : (C) 2002-2021 by Andre Simon
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -36,7 +36,7 @@ namespace Help
 {
 /** print help message to stdout
  */
-void printHelp();
+void printHelp(const std::string &topic);
 }
 
 #endif
