@@ -188,7 +188,7 @@ void ASEnhancer::convertSpaceIndentToForceTab(std::string& line) const
  * @param caseIndex     the line index of the case statement.
  * @return              the line index of the colon.
  */
-size_t ASEnhancer::findCaseColon(const std::string& line, size_t caseIndex) const
+size_t ASEnhancer::findCaseColon(std::string_view line, size_t caseIndex) const
 {
 	size_t i = caseIndex;
 	bool isInQuote_ = false;
@@ -276,9 +276,9 @@ int ASEnhancer::indentLine(std::string& line, int indent) const
  * @param index         the current line index.
  * @return              true if a hit.
  */
-bool ASEnhancer::isBeginDeclareSectionSQL(const std::string& line, size_t index) const
+bool ASEnhancer::isBeginDeclareSectionSQL(std::string_view line, size_t index) const
 {
-	std::string word;
+
 	size_t hits = 0;
 	size_t i;
 	for (i = index; i < line.length(); i++)
@@ -290,8 +290,8 @@ bool ASEnhancer::isBeginDeclareSectionSQL(const std::string& line, size_t index)
 			break;
 		if (!isCharPotentialHeader(line, i))
 			continue;
-		word = getCurrentWord(line, i);
-		for (char& character : word)
+		std::string_view word = getCurrentWord(line, i);
+		for (char character : word)
 			character = (char) toupper(character);
 		if (word == "EXEC" || word == "SQL")
 		{
@@ -325,9 +325,8 @@ bool ASEnhancer::isBeginDeclareSectionSQL(const std::string& line, size_t index)
  * @param index         the current line index.
  * @return              true if a hit.
  */
-bool ASEnhancer::isEndDeclareSectionSQL(const std::string& line, size_t index) const
+bool ASEnhancer::isEndDeclareSectionSQL(std::string_view line, size_t index) const
 {
-	std::string word;
 	size_t hits = 0;
 	size_t i;
 	for (i = index; i < line.length(); i++)
@@ -339,8 +338,8 @@ bool ASEnhancer::isEndDeclareSectionSQL(const std::string& line, size_t index) c
 			break;
 		if (!isCharPotentialHeader(line, i))
 			continue;
-		word = getCurrentWord(line, i);
-		for (char& character : word)
+		std::string_view word = getCurrentWord(line, i);
+		for (char character : word)
 			character = (char) toupper(character);
 		if (word == "EXEC" || word == "SQL")
 		{
@@ -374,7 +373,7 @@ bool ASEnhancer::isEndDeclareSectionSQL(const std::string& line, size_t index) c
  * @return     false = one-line brace has not been reached.
  *             true  = one-line brace has been reached.
  */
-bool ASEnhancer::isOneLineBlockReached(const std::string& line, int startChar) const
+bool ASEnhancer::isOneLineBlockReached(std::string_view line, int startChar) const
 {
 	assert(line[startChar] == '{');
 
@@ -619,7 +618,7 @@ void ASEnhancer::parseCurrentLine(std::string& line, bool isInPreprocessor, bool
 			// bypass the entire word
 			if (isPotentialKeyword)
 			{
-				std::string name = getCurrentWord(line, i);
+				std::string_view name = getCurrentWord(line, i);
 				i += name.length() - 1;
 			}
 			continue;
@@ -712,7 +711,7 @@ size_t ASEnhancer::processSwitchBlock(std::string& line, size_t index)
 	}
 	if (isPotentialKeyword)
 	{
-		std::string name = getCurrentWord(line, i);          // bypass the entire name
+		std::string_view name = getCurrentWord(line, i);          // bypass the entire name
 		i += name.length() - 1;
 	}
 	return i;
