@@ -631,7 +631,7 @@ void ASResource::buildPreDefinitionHeaders(std::vector<const std::string*>* preD
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 // check if a specific line position contains a header.
-const std::string* ASBase::findHeader(const std::string& line, int i,
+const std::string* ASBase::findHeader(std::string_view line, int i,
                                       const std::vector<const std::string*>* possibleHeaders) const
 {
 	assert(isCharPotentialHeader(line, i));
@@ -671,7 +671,7 @@ const std::string* ASBase::findHeader(const std::string& line, int i,
 }
 
 // check if a specific line position contains a keyword.
-bool ASBase::findKeyword(const std::string& line, int i, const std::string& keyword) const
+bool ASBase::findKeyword(std::string_view  line, int i, std::string_view keyword) const
 {
 	assert(isCharPotentialHeader(line, i));
 	// check the word
@@ -700,7 +700,7 @@ bool ASBase::findKeyword(const std::string& line, int i, const std::string& keyw
 }
 
 // check if a specific line position contains an operator.
-const std::string* ASBase::findOperator(const std::string& line, int i,
+const std::string* ASBase::findOperator(std::string_view line, int i,
                                         const std::vector<const std::string*>* possibleOperators) const
 {
 	assert(isCharPotentialOperator(line[i]));
@@ -721,7 +721,7 @@ const std::string* ASBase::findOperator(const std::string& line, int i,
 
 // get the current word on a line
 // index must point to the beginning of the word
-std::string ASBase::getCurrentWord(const std::string& line, size_t index) const
+std::string_view ASBase::getCurrentWord(std::string_view line, size_t index) const
 {
 	//assert(isCharPotentialHeader(line, index));
 	size_t lineLength = line.length();
@@ -751,7 +751,7 @@ bool ASBase::isLegalNameChar(char ch) const
 }
 
 // check if a specific character can be part of a header
-bool ASBase::isCharPotentialHeader(const std::string& line, size_t i) const
+bool ASBase::isCharPotentialHeader(std::string_view line, size_t i) const
 {
 	assert(!isWhiteSpace(line[i]));
 	char prevCh = ' ';
@@ -787,7 +787,7 @@ bool ASBase::isDigit(char ch) const
 }
 
 // check if a specific character is a digit separator
-bool ASBase::isDigitSeparator(const std::string& line, int i) const
+bool ASBase::isDigitSeparator(std::string_view line, int i) const
 {
 	assert(line[i] == '\'');
 	// casting to (unsigned char) eliminates negative characters
@@ -800,7 +800,7 @@ bool ASBase::isDigitSeparator(const std::string& line, int i) const
 }
 
 // peek at the next unread character.
-char ASBase::peekNextChar(const std::string& line, int i) const
+char ASBase::peekNextChar(std::string_view  line, int i) const
 {
 	char ch = ' ';
 	size_t peekNum = line.find_first_not_of(" \t", i + 1);
