@@ -32,6 +32,13 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "htmlgenerator.h"
 #include "version.h"
 
+using std::ofstream;
+using std::ostringstream;
+using std::right;
+using std::setw;
+using std::string;
+using std::vector;
+
 namespace highlight
 {
 
@@ -202,7 +209,7 @@ string HtmlGenerator::getAttributes ( const string & elemName, const ElementStyl
             << ( elem.isUnderline() ? "; text-decoration:underline" :"" );
     }
 
-    string customStyle(elem.getCustomStyle());
+    string customStyle(elem.getCustomAttribute());
 
     if (!customStyle.empty()) {
         if (!elem.getCustomOverride()) {
