@@ -29,6 +29,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "pangogenerator.h"
 
+using std::ostringstream;
+using std::string;
+
 namespace highlight
 {
 
@@ -52,7 +55,7 @@ string PangoGenerator::getAttributes ( const ElementStyle & elem )
         << ( elem.isUnderline() ? " underline=\"single\"" :"" );
     }
 
-    string customStyle(elem.getCustomStyle());
+    string customStyle(elem.getCustomAttribute());
 
     if (!customStyle.empty()) {
         if (!elem.getCustomOverride()) {
