@@ -31,6 +31,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "svggenerator.h"
 
+using std::ostringstream;
+using std::string;
+
 namespace highlight
 {
 
@@ -132,7 +135,7 @@ string SVGGenerator::getAttributes ( const string & elemName,
             << ( elem.isUnderline() ? "; text-decoration:underline" :"" );
     }
 
-    string customStyle(elem.getCustomStyle());
+    string customStyle(elem.getCustomAttribute());
 
     if (!customStyle.empty()) {
         if (!elem.getCustomOverride()) {
