@@ -30,6 +30,12 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "keystore.h"
 #include "enums.h"
 
+using std::iterator;
+using std::ostringstream;
+using std::set;
+using std::string;
+using std::vector;
+
 namespace highlight
 {
 
@@ -191,12 +197,12 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
             Diluculum::LuaValueMap categoryMap;
             categoryMap = ls["Categories"].value().asTable();
 
-            for(Diluculum::LuaValueMap::const_iterator it = categoryMap.begin(); it != categoryMap.end(); ++it)
+            for (const auto &[first, second] : categoryMap)
             {
-                categories.append(it->second.asString());
-                if (std::next(it) != categoryMap.end()) {
+                if (!categories.empty()) {
                     categories.append(",");
                 }
+                categories.append(second.asString());
             }
         }
 
