@@ -31,6 +31,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "texgenerator.h"
 
+using std::ostringstream;
+using std::string;
+
 namespace highlight
 {
 
@@ -93,7 +96,7 @@ string TexGenerator::getAttributes ( const string & elemName,const ElementStyle
             << ( elem.getColour().getBlue ( TEX ) ) <<" 0.0}";
     }
 
-    string customStyle(elem.getCustomStyle());
+    string customStyle(elem.getCustomAttribute());
 
     if (!customStyle.empty()) {
         s << customStyle;
@@ -296,9 +299,8 @@ string TexGenerator::getStyleDefinition()
         os << getAttributes ( STY_NAME_ERR, docStyle.getErrorStyle() );
         os << getAttributes ( STY_NAME_ERM, docStyle.getErrorMessageStyle() );
 
-        KeywordStyles styles = docStyle.getKeywordStyles();
-        for ( KSIterator it=styles.begin(); it!=styles.end(); it++ ) {
-            os << getAttributes ( it->first, it->second );
+        for ( const auto &[first, second] : docStyle.getKeywordStyles() ) {
+            os << getAttributes ( first, second );
         }
 
         os <<  "% The special option is not supported by all dvi drivers\n"
