@@ -21,6 +21,7 @@
 #include <iostream>		// for cout
 #include <memory>
 #include <string>
+#include <string_view>
 #include <vector>
 
 #ifdef __GNUC__
@@ -52,6 +53,8 @@
 	#pragma clang diagnostic ignored "-Wshorten-64-to-32"
 #endif
 
+#define ASTYLE_VERSION "3.4.16"
+
 //-----------------------------------------------------------------------------
 // astyle namespace
 //-----------------------------------------------------------------------------
@@ -62,7 +65,7 @@ namespace astyle {
 // definitions
 //----------------------------------------------------------------------------
 
-enum FileType { C_TYPE = 0, JAVA_TYPE = 1, SHARP_TYPE = 2, JS_TYPE = 3, OBJC_TYPE = 4, INVALID_TYPE = -1 };
+enum FileType { C_TYPE = 0, JAVA_TYPE = 1, SHARP_TYPE = 2, JS_TYPE = 3, OBJC_TYPE = 4, GHC_TYPE = 5, INVALID_TYPE = -1 };
 
 /* The enums below are not recognized by 'vectors' in Microsoft Visual C++
    V5 when they are part of a namespace!!!  Use Visual C++ V6 or higher.
@@ -265,11 +268,11 @@ public:
 	static const std::string AS_OPEN_LINE_COMMENT, AS_OPEN_COMMENT, AS_CLOSE_COMMENT;
 	static const std::string AS_BAR_DEFINE, AS_BAR_INCLUDE, AS_BAR_IF, AS_BAR_EL, AS_BAR_ENDIF;
 	static const std::string AS_AUTO, AS_RETURN;
-	static const std::string AS_CIN, AS_COUT, AS_CERR;
+	static const std::string AS_CIN, AS_COUT, AS_CERR, AS_MAPPING;
 	static const std::string AS_ASSIGN, AS_PLUS_ASSIGN, AS_MINUS_ASSIGN, AS_MULT_ASSIGN;
 	static const std::string AS_DIV_ASSIGN, AS_MOD_ASSIGN, AS_XOR_ASSIGN, AS_OR_ASSIGN, AS_AND_ASSIGN;
 	static const std::string AS_GR_GR_ASSIGN, AS_LS_LS_ASSIGN, AS_GR_GR_GR_ASSIGN, AS_LS_LS_LS_ASSIGN;
-	static const std::string AS_GCC_MIN_ASSIGN, AS_GCC_MAX_ASSIGN, AS_SPACESHIP, AS_EQUAL_JS;
+	static const std::string AS_GCC_MIN_ASSIGN, AS_GCC_MAX_ASSIGN, AS_SPACESHIP, AS_EQUAL_JS, AS_COALESCE_CS;
 	static const std::string AS_EQUAL, AS_PLUS_PLUS, AS_MINUS_MINUS, AS_NOT_EQUAL, AS_GR_EQUAL;
 	static const std::string AS_LS_EQUAL, AS_LS_LS_LS, AS_LS_LS, AS_GR_GR_GR, AS_GR_GR;
 	static const std::string AS_QUESTION_QUESTION, AS_LAMBDA;
@@ -277,7 +280,7 @@ public:
 	static const std::string AS_SCOPE_RESOLUTION;
 	static const std::string AS_PLUS, AS_MINUS, AS_MULT, AS_DIV, AS_MOD, AS_GR, AS_LS;
 	static const std::string AS_NOT, AS_BIT_XOR, AS_BIT_OR, AS_BIT_AND, AS_BIT_NOT;
-	static const std::string AS_QUESTION, AS_COLON, AS_SEMICOLON, AS_COMMA;
+	static const std::string AS_QUESTION, AS_COLON, AS_SEMICOLON, AS_COMMA, AS_DOT;
 	static const std::string AS_ASM, AS__ASM__, AS_MS_ASM, AS_MS__ASM;
 	static const std::string AS_QFOREACH, AS_QFOREVER, AS_FOREVER;
 	static const std::string AS_FOREACH, AS_LOCK, AS_UNSAFE, AS_FIXED;
@@ -303,28 +306,28 @@ protected:
 
 protected:  // inline functions
 	void init(int fileTypeArg) { baseFileType = fileTypeArg; }
-	bool isCStyle() const { return baseFileType == C_TYPE || baseFileType == OBJC_TYPE; }
+	bool isCStyle() const { return baseFileType == C_TYPE || baseFileType == OBJC_TYPE || baseFileType == GHC_TYPE; }
 	bool isJavaStyle() const { return baseFileType == JAVA_TYPE; }
 	bool isSharpStyle() const { return baseFileType == SHARP_TYPE; }
 	bool isJSStyle() const { return baseFileType == JS_TYPE; }
 	bool isObjCStyle() const { return baseFileType == OBJC_TYPE; }
+	bool isGHCStyle() const { return baseFileType == GHC_TYPE; }
 
 	bool isWhiteSpace(char ch) const { return (ch == ' ' || ch == '\t'); }
 
 protected:  // functions definitions are at the end of ASResource.cpp
-	const std::string* findHeader(const std::string& line, int i,
+	const std::string* findHeader(std::string_view line, int i,
 	                              const std::vector<const std::string*>* possibleHeaders) const;
-	bool findKeyword(const std::string& line, int i, const std::string& keyword) const;
-	const std::string* findOperator(const std::string& line, int i,
+	bool findKeyword(std::string_view  line, int i, std::string_view  keyword) const;
+	const std::string* findOperator(std::string_view  line, int i,
 	                                const std::vector<const std::string*>* possibleOperators) const;
-	std::string getCurrentWord(const std::string& line, size_t index) const;
+	std::string_view getCurrentWord(std::string_view, size_t index) const;
 	bool isDigit(char ch) const;
 	bool isLegalNameChar(char ch) const;
-	bool isCharPotentialHeader(const std::string& line, size_t i) const;
+	bool isCharPotentialHeader(std::string_view line, size_t i) const;
 	bool isCharPotentialOperator(char ch) const;
-	bool isDigitSeparator(const std::string& line, int i) const;
-	char peekNextChar(const std::string& line, int i) const;
-
+	bool isDigitSeparator(std::string_view line, int i) const;
+	char peekNextChar(std::string_view line, int i) const;
 };  // Class ASBase
 
 //-----------------------------------------------------------------------------
@@ -355,6 +358,8 @@ public:
 	void setJSStyle();
 	void setObjCStyle();
 	void setSharpStyle();
+	void setGHCStyle();
+
 
 	void setLabelIndent(bool state);
 	void setMaxContinuationIndentLength(int max);
@@ -393,14 +398,14 @@ public:
 
 protected:
 	void deleteBeautifierVectors();
-	int  getNextProgramCharDistance(const std::string& line, int i) const;
+	int  getNextProgramCharDistance(std::string_view line, int i) const;
 	int  indexOf(const std::vector<const std::string*>& container, const std::string* element) const;
 	void setBlockIndent(bool state);
 	void setBraceIndent(bool state);
 	void setBraceIndentVtk(bool state);
-	std::string extractPreprocessorStatement(const std::string& line) const;
-	std::string trim(const std::string& str) const;
-	std::string rtrim(const std::string& str) const;
+	std::string extractPreprocessorStatement(std::string_view line) const;
+	std::string trim(std::string_view str) const;
+	std::string rtrim(std::string_view str) const;
 
 	// variables set by ASFormatter - must be updated in activeBeautifierStack
 	int  inLineNumber;
@@ -417,18 +422,20 @@ protected:
 	bool isInBeautifySQL;
 	bool isInIndentableStruct;
 	bool isInIndentablePreproc;
+	bool lambdaIndicator;
+
 
 private:  // functions
-	void adjustObjCMethodDefinitionIndentation(const std::string& line_);
-	void adjustObjCMethodCallIndentation(const std::string& line_);
+	void adjustObjCMethodDefinitionIndentation(std::string_view line_);
+	void adjustObjCMethodCallIndentation(std::string_view line_);
 	void adjustParsedLineIndentation(size_t iPrelim, bool isInExtraHeaderIndent);
-	void computePreliminaryIndentation();
-	void parseCurrentLine(const std::string& line);
+	void computePreliminaryIndentation(std::string_view line);
+	void parseCurrentLine(std::string_view line);
 	void popLastContinuationIndent();
-	void processPreprocessor(const std::string& preproc, const std::string& line);
-	void registerContinuationIndent(const std::string& line, int i, int spaceIndentCount_,
+	void processPreprocessor(std::string_view preproc, std::string_view line);
+	void registerContinuationIndent(std::string_view line, int i, int spaceIndentCount_,
 	                                int tabIncrementIn, int minIndent, bool updateParenStack);
-	void registerContinuationIndentColon(const std::string& line, int i, int tabIncrementIn);
+	void registerContinuationIndentColon(std::string_view line, int i, int tabIncrementIn);
 	void initVectors();
 	void initTempStacksContainer(std::vector<std::vector<const std::string*>*>*& container,
 	                             std::vector<std::vector<const std::string*>*>* value);
@@ -436,20 +443,20 @@ private:  // functions
 	void deleteBeautifierContainer(std::vector<ASBeautifier*>*& container);
 	void deleteTempStacksContainer(std::vector<std::vector<const std::string*>*>*& container);
 	int  adjustIndentCountForBreakElseIfComments() const;
-	int  computeObjCColonAlignment(const std::string& line, int colonAlignPosition) const;
+	int  computeObjCColonAlignment(std::string_view line, int colonAlignPosition) const;
 	int  convertTabToSpaces(int i, int tabIncrementIn) const;
-	int  findObjCColonAlignment(const std::string& line) const;
-	int  getContinuationIndentAssign(const std::string& line, size_t currPos) const;
-	int  getContinuationIndentComma(const std::string& line, size_t currPos) const;
-	int  getObjCFollowingKeyword(const std::string& line, int bracePos) const;
-	bool isIndentedPreprocessor(const std::string& line, size_t currPos) const;
-	bool isLineEndComment(const std::string& line, int startPos) const;
-	bool isPreprocessorConditionalCplusplus(const std::string& line) const;
-	bool isInPreprocessorUnterminatedComment(const std::string& line);
+	int  findObjCColonAlignment(std::string_view line) const;
+	int  getContinuationIndentAssign(std::string_view line, size_t currPos) const;
+	int  getContinuationIndentComma(std::string_view line, size_t currPos) const;
+	int  getObjCFollowingKeyword(std::string_view line, int bracePos) const;
+	bool isIndentedPreprocessor(std::string_view line, size_t currPos) const;
+	bool isLineEndComment(std::string_view line, int startPos) const;
+	bool isPreprocessorConditionalCplusplus(std::string_view line) const;
+	bool isInPreprocessorUnterminatedComment(std::string_view line);
 	bool isTopLevel() const;
-	bool statementEndsWithComma(const std::string& line, int index) const;
-	const std::string& getIndentedLineReturn(const std::string& newLine, const std::string& originalLine) const;
-	std::string getIndentedSpaceEquivalent(const std::string& line_) const;
+	bool statementEndsWithComma(std::string_view line, int index) const;
+
+	std::string getIndentedSpaceEquivalent(std::string_view line_) const;
 	std::string preLineWS(int lineIndentCount, int lineSpaceIndentCount) const;
 	template<typename T> void deleteContainer(T& container);
 	template<typename T> void initContainer(T& container, T value);
@@ -555,9 +562,12 @@ private:  // variables
 	bool foundPreCommandMacro;
 	bool shouldAlignMethodColon;
 	bool shouldIndentPreprocConditional;
-	bool lambdaIndicator;
 	bool squeezeWhitespace;
 	bool attemptLambdaIndentation;
+
+	bool isInAssignment;
+	bool isInInitializerList;
+
 	int  indentCount;
 	int  spaceIndentCount;
 	int  spaceIndentObjCMethodAlignment;
@@ -592,6 +602,8 @@ private:  // variables
 // Class ASEnhancer
 //-----------------------------------------------------------------------------
 
+// TODO rewrite methods to return altered stings
+
 class ASEnhancer : protected ASBase
 {
 public:  // functions
@@ -603,11 +615,11 @@ public:  // functions
 private:  // functions
 	void   convertForceTabIndentToSpaces(std::string&  line) const;
 	void   convertSpaceIndentToForceTab(std::string& line) const;
-	size_t findCaseColon(const std::string&  line, size_t caseIndex) const;
+	size_t findCaseColon(std::string_view line, size_t caseIndex) const;
 	int    indentLine(std::string&  line, int indent) const;
-	bool   isBeginDeclareSectionSQL(const std::string&  line, size_t index) const;
-	bool   isEndDeclareSectionSQL(const std::string&  line, size_t index) const;
-	bool   isOneLineBlockReached(const std::string& line, int startChar) const;
+	bool   isBeginDeclareSectionSQL(std::string_view  line, size_t index) const;
+	bool   isEndDeclareSectionSQL(std::string_view  line, size_t index) const;
+	bool   isOneLineBlockReached(std::string_view line, int startChar) const;
 	void   parseCurrentLine(std::string& line, bool isInPreprocessor, bool isInSQL);
 	size_t processSwitchBlock(std::string&  line, size_t index);
 	int    unindentLine(std::string&  line, int unindent) const;
@@ -682,7 +694,7 @@ public:	// functions
 	LineEndFormat getLineEndFormat() const;
 	bool getIsLineReady() const;
 	void setFormattingStyle(FormatStyle style);
-	void setAddBracesMode(bool state);
+	void setAddBracesMode(int state);
 	void setAddOneLineBracesMode(bool state);
 	void setRemoveBracesMode(bool state);
 	void setAttachClass(bool state);
@@ -719,6 +731,9 @@ public:	// functions
 	void setOperatorPaddingMode(bool state);
 	void setParensOutsidePaddingMode(bool state);
 	void setParensFirstPaddingMode(bool state);
+
+	void setEmptyParensPaddingMode(bool state);
+
 	void setParensInsidePaddingMode(bool state);
 	void setParensHeaderPaddingMode(bool state);
 	void setParensUnPaddingMode(bool state);
@@ -751,8 +766,8 @@ private:  // functions
 	char peekNextChar() const;
 	BraceType getBraceType();
 	bool adjustChecksumIn(int adjustment);
-	bool computeChecksumIn(const std::string& currentLine_);
-	bool computeChecksumOut(const std::string& beautifiedLine);
+	bool computeChecksumIn(std::string_view currentLine_);
+	bool computeChecksumOut(std::string_view beautifiedLine);
 	bool addBracesToStatement();
 	bool removeBracesFromStatement();
 	bool commentAndHeaderFollows();
@@ -768,22 +783,22 @@ private:  // functions
 	bool isClosingHeader(const std::string* header) const;
 	bool isCurrentBraceBroken() const;
 	bool isDereferenceOrAddressOf() const;
-	bool isExecSQL(const std::string& line, size_t index) const;
-	bool isEmptyLine(const std::string& line) const;
+	bool isExecSQL(std::string_view line, size_t index) const;
+	bool isEmptyLine(std::string_view line) const;
 	bool isExternC() const;
 	bool isMultiStatementLine() const;
 	bool isNextWordSharpNonParenHeader(int startChar) const;
 	bool isNonInStatementArrayBrace() const;
-	bool isNumericVariable(const std::string& word) const;
+	bool isNumericVariable(std::string_view word) const;
 	bool isOkToSplitFormattedLine();
 	bool isPointerOrReference() const;
 	bool isPointerOrReferenceCentered() const;
-	bool isPointerOrReferenceVariable(const std::string& word) const;
-	bool isPointerToPointer(const std::string& line, int currPos) const;
+	bool isPointerOrReferenceVariable(std::string_view word) const;
+	bool isPointerToPointer(std::string_view line, int currPos) const;
 	bool isSharpStyleWithParen(const std::string* header) const;
 	bool isStructAccessModified(const std::string& firstLine, size_t index) const;
 	bool isIndentablePreprocessorBlock(const std::string& firstLine, size_t index);
-	bool isNDefPreprocStatement(const std::string& nextLine_, const std::string& preproc) const;
+	bool isNDefPreprocStatement(std::string_view nextLine_, std::string_view preproc) const;
 	bool isUnaryOperator() const;
 	bool isUniformInitializerBrace() const;
 	bool isImmediatelyPostCast() const;
@@ -796,19 +811,19 @@ private:  // functions
 	int  findObjCColonAlignment() const;
 	int  getCurrentLineCommentAdjustment();
 	int  getNextLineCommentAdjustment();
-	int  isOneLineBlockReached(const std::string& line, int startChar) const;
+	int  isOneLineBlockReached(std::string_view line, int startChar) const;
 	void adjustComments();
 	void appendChar(char ch, bool canBreakLine);
 	void appendCharInsideComments();
 	void appendClosingHeader();
-	void appendOperator(const std::string& sequence, bool canBreakLine = true);
-	void appendSequence(const std::string& sequence, bool canBreakLine = true);
+	void appendOperator(std::string_view sequence, bool canBreakLine = true);
+	void appendSequence(std::string_view sequence, bool canBreakLine = true);
 	void appendSpacePad();
 	void appendSpaceAfter();
 	void breakLine(bool isSplitLine = false);
 	void buildLanguageVectors();
 	void updateFormattedLineSplitPoints(char appendedChar);
-	void updateFormattedLineSplitPointsOperator(const std::string& sequence);
+	void updateFormattedLineSplitPointsOperator(std::string_view sequence);
 	void checkIfTemplateOpener();
 	void clearFormattedLineSplitPoints();
 	void convertTabToSpaces();
@@ -850,11 +865,11 @@ private:  // functions
 	void trimContinuationLine();
 	void updateFormattedLineSplitPointsPointerOrReference(size_t index);
 	size_t findFormattedLineSplitPoint() const;
-	size_t findNextChar(const std::string& line, char searchChar, int searchStart = 0) const;
-	const std::string* checkForHeaderFollowingComment(const std::string& firstLine) const;
+	size_t findNextChar(std::string_view line, char searchChar, int searchStart = 0) const;
+	const std::string* checkForHeaderFollowingComment(std::string_view firstLine) const;
 	const std::string* getFollowingOperator() const;
-	std::string getPreviousWord(const std::string& line, int currPos) const;
-	std::string peekNextText(const std::string& firstLine,
+	std::string getPreviousWord(const std::string& line, int currPos, bool allowDots = false) const;
+	std::string peekNextText(std::string_view firstLine,
 	                         bool endOnEmptyLine = false,
 	                         const std::shared_ptr<ASPeekStream>& streamArg = nullptr) const;
 
@@ -883,6 +898,7 @@ private:  // variables
 	std::string readyFormattedLine;
 	std::string verbatimDelimiter;
 	const std::string* currentHeader;
+	const std::string* previousHeader;
 	char currentChar;
 	char previousChar;
 	char previousNonWSChar;
@@ -899,8 +915,9 @@ private:  // variables
 	int  templateDepth;
 	int  squareBracketCount;
 	int  parenthesesCount;
-	int  squeezeEmptyLineNum;
-	int  squeezeEmptyLineCount;
+	int  closingBracesCount;
+	size_t  squeezeEmptyLineNum;
+	size_t  squeezeEmptyLineCount;
 
 	size_t checksumIn;
 	size_t checksumOut;
@@ -939,6 +956,8 @@ private:  // variables
 	bool shouldPadOperators;
 	bool shouldPadParensOutside;
 	bool shouldPadFirstParen;
+
+	bool shouldPadEmptyParens;
 	bool shouldPadParensInside;
 	bool shouldPadHeader;
 	bool shouldStripCommentPrefix;
@@ -1031,7 +1050,7 @@ private:  // variables
 	bool shouldBreakClosingHeaderBraces;
 	bool shouldBreakElseIfs;
 	bool shouldBreakLineAfterLogical;
-	bool shouldAddBraces;
+	int  shouldAddBraces;
 	bool shouldAddOneLineBraces;
 	bool shouldRemoveBraces;
 	bool shouldPadMethodColon;
@@ -1083,15 +1102,20 @@ private:  // variables
 	bool isFirstPreprocConditional;
 	bool processedFirstConditional;
 	bool isJavaStaticConstructor;
+	bool isInAllocator;
+	bool isInMultlineStatement;
+	int isInExplicitBlock;
 
 private:  // inline functions
-	// append the CURRENT character (curentChar) to the current formatted line.
+	// append the CURRENT character (currentChar) to the current formatted line.
 	void appendCurrentChar(bool canBreakLine = true)
 	{ appendChar(currentChar, canBreakLine); }
 
 	// check if a specific sequence exists in the current placement of the current line
-	bool isSequenceReached(const char* sequence) const
-	{ return currentLine.compare(charNum, strlen(sequence), sequence) == 0; }
+	bool isSequenceReached(std::string_view sequence) const
+	{
+    	return currentLine.compare(charNum, sequence.length(), sequence) == 0;
+	}
 
 	// call ASBase::findHeader for the current character
 	const std::string* findHeader(const std::vector<const std::string*>* headers_)
