@@ -43,10 +43,7 @@ namespace highlight
 {
 
 /** maps keyword class names and the corresponding formatting information*/
-typedef map <std::string, ElementStyle> KeywordStyles;
-
-/** iterator for keyword styles*/
-typedef KeywordStyles::const_iterator KSIterator;
+typedef std::map <std::string, ElementStyle> KeywordStyles;
 
 /** \brief Contains information about document formatting properties.
  * @author Andre Simon
@@ -67,7 +64,7 @@ private:
 
     std::vector<Diluculum::LuaFunction*> pluginChunks;
 
-    map<std::string, int> semanticStyleMap;
+    std::map<std::string, int> semanticStyleMap;
 
     bool fileOK, restoreStyles, dirtyAttributes;
 
